.. hidden image:: https://travis-ci.org/ronpandolfi/Xi-cam.svg?branch=master
.. image:: https://readthedocs.org/projects/xi-cam/badge/?version=latest

Xi-cam
======

About Xi-cam
------------

Xi-cam is a graphical environment for synchrotron data analysis,
management, and visualization developed by the Advanced Light Source at
Lawrence Berkeley National Laboratory. This is a cross-platform
open-source Python project licensed under BSD.

Installation
------------

Linux
+++++

To install Xi-cam, you must first have ``numpy`` and ``scipy`` installed. You can install these with:

.. code-block:: bash

 pip install numpy scipy

You can then install Xi-cam with:

.. code-block:: bash

 pip install xicam

Windows
+++++++

Download the Xi-cam windows installer (coming soon).


Mac OS X 10.10+
+++++++++++++++

Download the Xi-cam Mac .app (coming soon).


Copyright Notice
----------------

“Xi-cam”, Copyright (c) 2016, The Regents of the University of
California, through Lawrence Berkeley National Laboratory (subject to
receipt of any required approvals from the U.S. Dept. of Energy). All
rights reserved.

If you have questions about your rights to use or distribute this
software, please contact Berkeley Lab’s Innovation & Partnerships Office
at IPO@lbl.gov.

NOTICE. This Software was developed under funding from the U.S.
Department of Energy and the U.S. Government consequently retains
certain rights. As such, the U.S. Government has been granted for itself
and others acting on its behalf a paid-up, nonexclusive, irrevocable,
worldwide license in the Software to reproduce, distribute copies to the
public, prepare derivative works, and perform publicly and display
publicly, and to permit other to do so.